@@ -1,6 +1,7 @@
 pub mod indices;
 pub mod merge;
 use std::ops::{Deref,DerefMut};
+use std::fmt::Write;
 
 /// macro `here!()` gives `&str` with the current `file:line path::function` for error messages.
 #[macro_export]
@@ -15,6 +16,25 @@ macro_rules! here {
     }}
 }
 
+/// Helper function `write vector`. Formats Vec<T> as a space separated list 
+/// that can be Displayed without recourse to Debug.
+/// This must be done in Rust item by item, hence the iteration.
+/// You can remove the green colour incantations at the beginning
+/// and at the end, if not wanted.
+pub fn wv<T>(v: &[T]) -> String where T:Copy+std::fmt::Display {
+    let s =
+        v.iter().fold(String::from("\x1B[01;92m[ "),
+        |mut s,&n| {write!(s,"{} ",n).ok(); s} )
+        +"]\x1B[0m";
+    s
+}
+
+/// Helper function to format in green a single item. 
+pub fn wi<T>(item: &T) -> String where T:std::fmt::Display {
+    let s = String::from("\x1B[01;92m");
+    s + &item.to_string() + "\x1B[0m"
+}
+
 /// GreenIt (GI) struct facilitates printing (in green) any
 /// singular type that has Display implemented.
 #[derive(Eq, Debug, Clone, Copy, PartialEq)]
@@ -61,6 +81,8 @@ impl<'a, T: std::fmt::Display> std::fmt::Display for GS<'a,T> {
 
 /// Methods to manipulate indices of `Vec<usize>` type.
 pub trait Indices { 
+    /// Reverse an index slice by simple reverse iteration.
+    fn revindex(self) -> Vec<usize>; 
     /// Invert an index.
     fn invindex(self) -> Vec<usize>;
     /// complement of the index - turns ranks from/to ascending/descending
